<?php
require_once __DIR__ . '/config/helpers.php';
require_user();
include __DIR__ . '/header.php';
?>
<div class="row justify-content-center">
  <div class="col-lg-9">
    <div class="card card-pink p-4">
      <h3 class="text-center mb-2" style="color:#d63384;">Menú principal</h3>
      <p class="text-center text-muted mb-1">Sistema simple para cargar fichas médicas de seguimiento.</p>
      <p class="text-center"><span class="badge badge-pink fs-6">Paciente actual: <?= e(current_patient_name()) ?></span></p>
      <div class="row g-3 mt-2">
        <div class="col-md-6"><a class="btn btn-pink w-100 py-3" href="seguimiento/create.php">Cargar nueva ficha</a></div>
        <div class="col-md-6"><a class="btn btn-outline-danger w-100 py-3" href="seguimiento/index.php">Ver seguimientos</a></div>
        <div class="col-md-3"><a class="btn btn-light border w-100 py-3" href="procedimientos/index.php">Procedimientos</a></div>
        <div class="col-md-3"><a class="btn btn-light border w-100 py-3" href="medicamentos/index.php">Medicamentos</a></div>
        <div class="col-md-3"><a class="btn btn-light border w-100 py-3" href="pacientes/index.php">Pacientes</a></div>
        <div class="col-md-3"><a class="btn btn-light border w-100 py-3" href="usuarios/index.php">Usuarios</a></div>
      </div>
    </div>
  </div>
</div>
<?php include __DIR__ . '/footer.php'; ?>
