<?php require_once __DIR__ . '/config/helpers.php'; ?>
<!doctype html>
<html lang="es">
<head>
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <title>Ficha Médica de Seguimiento</title>
  <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet">
  <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
  <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
  <link href="/ficha_medica/assets/css/style.css" rel="stylesheet">
</head>
<body>
<nav class="navbar navbar-expand-lg navbar-dark navbar-custom mb-4">
  <div class="container">
    <a class="navbar-brand fw-bold" href="/ficha_medica/index.php">Ficha Médica</a>
    <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#menu">
      <span class="navbar-toggler-icon"></span>
    </button>
    <div class="collapse navbar-collapse" id="menu">
      <ul class="navbar-nav me-auto">
        <li class="nav-item"><a class="nav-link" href="/ficha_medica/seguimiento/index.php">Seguimientos</a></li>
        <li class="nav-item"><a class="nav-link" href="/ficha_medica/seguimiento/create.php">Nueva ficha</a></li>
        <li class="nav-item"><a class="nav-link" href="/ficha_medica/procedimientos/index.php">Procedimientos</a></li>
        <li class="nav-item"><a class="nav-link" href="/ficha_medica/medicamentos/index.php">Medicamentos</a></li>
        <li class="nav-item"><a class="nav-link" href="/ficha_medica/pacientes/index.php">Pacientes</a></li>
        <li class="nav-item"><a class="nav-link" href="/ficha_medica/usuarios/index.php">Usuarios</a></li>
      </ul>
      <?php if (current_user_id()): ?>
        <span class="navbar-text me-3">Usuario: <strong><?= e(current_user_name()) ?></strong> | Paciente: <strong><?= e(current_patient_name()) ?></strong></span>
        <a class="btn btn-light btn-sm" href="/ficha_medica/auth/logout.php">Cambiar</a>
      <?php endif; ?>
    </div>
  </div>
</nav>
<div class="container pb-5">
